from markupsafe import Markup

from .styles import ERROR, INFO


class Message:
    def __init__(self, style, header="", body=""):
        self.header = Markup(header)
        self.body = Markup(body)
        self.style = style


class MessageEncoder:
    """
    Encode `Message` as a primitive dictionary
    to be passed to and read from views.
    """

    @staticmethod
    def encode(msg):
        return {"header": msg.header, "body": msg.body, "style": msg.style.__dict__}


###############################################################
#  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  | #
###############################################################


def login_manager_message():
    return MessageEncoder.encode(
        Message(
            header="<h3><strong>Login Required.</strong></h3>",
            body="<p>You need to be logged in to access this page.</p>",
            style=INFO,
        )
    )


def login_unsuccessful_error():
    return MessageEncoder.encode(
        Message(
            header="<h3><strong>Login failed</strong></h3>",
            body="<p>You have attempted access with an invalid combination of login and password.</p>",
            style=ERROR,
        )
    )


def project_not_found():
    return MessageEncoder.encode(
        Message(
            header="<h3><strong>Project not found</strong></h3>",
            body="<p>The selected project could not be found.</p>",
            style=ERROR,
        )
    )


def shortlist_not_found():
    return MessageEncoder.encode(
        Message(
            header="<h3><strong>Shortlist not found</strong></h3>",
            body="<p>The selected shortlisting could not be found.</p>",
            style=ERROR,
        )
    )


def deadline_expired_for_students():
    return MessageEncoder.encode(
        Message(
            header="<h3><strong>Deadline expired</strong></h3>",
            body="<p>The deadline to make changes has now expired, and you cannot make changes to your shortlisting and ranking. If you have questions, please contact Lorenzo Picinali.</p>",
            style=ERROR,
        )
    )


def deadline_expired_for_staff():
    return MessageEncoder.encode(
        Message(
            header="<h3><strong>Deadline expired</strong></h3>",
            body="<p>The deadline to make changes has now expired, and you cannot make further changes. If you have questions, please contact Lorenzo Picinali.</p>",
            style=ERROR,
        )
    )
